@@ -109,10 +109,7 @@ dwd_open (SF_PRIVATE *psf)
 static int
 dwd_close	(SF_PRIVATE  *psf)
 {
-
-	if (psf->fdata)
-		free (psf->fdata) ;
-	psf->fdata = NULL ;
+	psf = psf ;
 
 	return 0 ;
 } /* dwd_close */
