@@ -141,23 +141,7 @@ static int
 mat5_close	(SF_PRIVATE  *psf)
 {
 	if (psf->mode == SFM_WRITE || psf->mode == SFM_RDWR)
-	{	/*  Now we know for certain the length of the file we can
-		 *  re-write correct values for the datasize header element.
-		 */
-
-		psf_fseek (psf, 0, SEEK_END) ;
-		psf->filelength = psf_ftell (psf) ;
-
-		psf->datalength = psf->filelength - psf->dataoffset ;
-		psf_fseek (psf, 0, SEEK_SET) ;
-
-		psf->sf.frames = psf->datalength / psf->blockwidth ;
-		mat5_write_header (psf, SF_FALSE) ;
-		} ;
-
-	if (psf->fdata)
-		free (psf->fdata) ;
-	psf->fdata = NULL ;
+		mat5_write_header (psf, SF_TRUE) ;
 
 	return 0 ;
 } /* mat5_close */
