@@ -758,20 +758,10 @@ msadpcm_close	(SF_PRIVATE  *psf)
 		if (pms->samplecount && pms->samplecount < pms->samplesperblock)
 			msadpcm_encode_block (psf, pms) ;	
 
-		psf_fseek (psf, 0, SEEK_END) ;
-		psf->filelength = psf_ftell (psf) ;
-
-		psf->sf.frames = pms->samplesperblock * pms->blockcount ;
-		psf->datalength = psf->filelength - psf->dataoffset ;
-
 		if (psf->write_header)
-			psf->write_header (psf, SF_FALSE) ;
+			psf->write_header (psf, SF_TRUE) ;
 		} ;
 
-	if (psf->fdata)
-		free (psf->fdata) ;
-	psf->fdata = NULL ;
-
 	return 0 ;
 } /* msadpcm_close */
 
