@@ -476,9 +476,6 @@ paf24_close (SF_PRIVATE  *psf)
 			paf24_write_block (psf, ppaf24) ;
 		} ;
 
-	free (psf->fdata) ;
-	psf->fdata = NULL ;
-
 	return 0 ;
 } /* paf24_close */
 
