@@ -413,9 +413,7 @@ voc_write_header (SF_PRIVATE *psf, int calc_length)
 	current = psf_ftell (psf) ;
 
 	if (calc_length)
-	{	psf_fseek (psf, 0, SEEK_END) ;
-		psf->filelength = psf_ftell (psf) ;
-		psf_fseek (psf, 0, SEEK_SET) ;
+	{	psf->filelength = psf_get_filelen (psf) ;
 
 		psf->datalength = psf->filelength - psf->dataoffset ;
 		if (psf->dataend)
@@ -531,13 +529,7 @@ voc_close	(SF_PRIVATE  *psf)
 		/* Write terminator */
 		psf_fwrite (&byte, 1, 1, psf) ;
 		
-		psf->filelength = psf_ftell (psf) ;
-		psf_fseek (psf, 0, SEEK_SET) ;
-		
-		psf->datalength = psf->filelength - psf->dataoffset ;
- 		psf->sf.frames = psf->datalength / (psf->bytewidth * psf->sf.channels) ;
-		
-		voc_write_header (psf, SF_FALSE) ;
+		voc_write_header (psf, SF_TRUE) ;
 		} ;
 
 	return 0 ;
