@@ -87,8 +87,8 @@ enum
 } ;
 
 /*------------------------------------------------------------------------------
- * Private static functions.
- */
+** Private static functions.
+*/
 
 static int	wav_read_header	(SF_PRIVATE *psf, int *blockalign, int *framesperblock) ;
 static int	wav_write_header (SF_PRIVATE *psf, int calc_length) ;
@@ -96,7 +96,7 @@ static int	wav_write_tailer (SF_PRIVATE *psf) ;
 static void wav_write_strings (SF_PRIVATE *psf, int location) ;
 static int	wav_command (SF_PRIVATE *psf, int command, void *data, int datasize) ;
 
-static int	wav_close	(SF_PRIVATE  *psf) ;
+static int	wav_close	(SF_PRIVATE *psf) ;
 
 static int 	wav_subchunk_parse	(SF_PRIVATE *psf, int chunk) ;
 static int	wav_read_smpl_chunk (SF_PRIVATE *psf, unsigned int chunklen) ;
@@ -113,7 +113,7 @@ wav_open	(SF_PRIVATE *psf)
 	if (psf->mode == SFM_READ || (psf->mode == SFM_RDWR && psf->filelength > 0))
 	{	if ((error = wav_read_header (psf, &blockalign, &framesperblock)))
 			return error ;
-		};
+		} ;
 
 	subformat = psf->sf.format & SF_FORMAT_SUBMASK ;
 
@@ -123,7 +123,7 @@ wav_open	(SF_PRIVATE *psf)
 
 		psf->endian = SF_ENDIAN_LITTLE ;	/* All WAV files are little endian. */
 
-		psf->blockwidth  = psf->bytewidth * psf->sf.channels ;
+		psf->blockwidth = psf->bytewidth * psf->sf.channels ;
 
 		if (psf->mode != SFM_RDWR || psf->filelength < 44)
 		{	psf->filelength = 0 ;
@@ -206,7 +206,7 @@ static int
 wav_read_header	(SF_PRIVATE *psf, int *blockalign, int *framesperblock)
 {	WAV_FMT		wav_fmt ;
 	FACT_CHUNK	fact_chunk ;
-	int			dword, marker, RIFFsize, done  = 0 ;
+	int			dword, marker, RIFFsize, done = 0 ;
 	int			parsestage = 0, error, format = 0 ;
 	char		*cptr ;
 
@@ -215,6 +215,7 @@ wav_read_header	(SF_PRIVATE *psf, int *blockalign, int *framesperblock)
 
 	while (! done)
 	{	psf_binheader_readf (psf, "m", &marker) ;
+
 		switch (marker)
 		{	case RIFF_MARKER :
 					if (parsestage)
@@ -222,12 +223,18 @@ wav_read_header	(SF_PRIVATE *psf, int *blockalign, int *framesperblock)
 
 					psf_binheader_readf (psf, "e4", &RIFFsize) ;
 
-					if (psf->filelength  < RIFFsize + 2 * SIGNED_SIZEOF (dword))
-					{	psf_log_printf (psf, "RIFF : %D (should be %D)\n", (sf_count_t) RIFFsize, psf->filelength - 2 * SIGNED_SIZEOF (dword)) ;
+					if (psf->fileoffset > 0 && psf->filelength > RIFFsize + 8)
+					{	/* Set file length. */
+						psf->filelength = RIFFsize + 8  ;
+						psf_log_printf (psf, "RIFF : %u\n", RIFFsize) ;
+						}
+					else if (psf->filelength < RIFFsize + 2 * SIGNED_SIZEOF (dword))
+					{	psf_log_printf (psf, "RIFF : %u (should be %D)\n", (sf_count_t) RIFFsize, psf->filelength - 2 * SIGNED_SIZEOF (dword)) ;
 						RIFFsize = dword ;
 						}
 					else
-						psf_log_printf (psf, "RIFF : %d\n", RIFFsize) ;
+						psf_log_printf (psf, "RIFF : %u\n", RIFFsize) ;
+
 					parsestage |= HAVE_RIFF ;
 					break ;
 
@@ -242,13 +249,17 @@ wav_read_header	(SF_PRIVATE *psf, int *blockalign, int *framesperblock)
 					if ((parsestage & (HAVE_RIFF | HAVE_WAVE)) != (HAVE_RIFF | HAVE_WAVE))
 						return SFE_WAV_NO_FMT ;
 
+					/* If this file has a SECOND fmt chunk, I don't want to know about it. */
+					if (parsestage & HAVE_fmt)
+						break ;
+
 					psf_binheader_readf (psf, "e4", &dword) ;
 					psf_log_printf (psf, "fmt  : %d\n", dword) ;
 
 					if ((error = wav_w64_read_fmt_chunk (psf, &wav_fmt, dword)))
 						return error ;
 
-					format     = wav_fmt.format ;
+					format = wav_fmt.format ;
 					parsestage |= HAVE_fmt ;
 					break ;
 
@@ -339,14 +350,14 @@ wav_read_header	(SF_PRIVATE *psf, int *blockalign, int *framesperblock)
 
 					cptr = (char *) psf->buffer ;
 					for (dword = 0 ; dword < psf->sf.channels ; dword++)
-					{	psf_binheader_readf (psf, "ef4", &(psf->peak.peak[dword].value),
-														&(psf->peak.peak[dword].position)) ;
+					{	psf_binheader_readf (psf, "ef4", &(psf->peak.peak [dword].value),
+														&(psf->peak.peak [dword].position)) ;
 
 						LSF_SNPRINTF (cptr, sizeof (psf->buffer), "    %2d   %-12d   %g\n",
-								dword, psf->peak.peak[dword].position, psf->peak.peak[dword].value) ;
+								dword, psf->peak.peak [dword].position, psf->peak.peak [dword].value) ;
 						cptr [sizeof (psf->buffer) - 1] = 0 ;
 						psf_log_printf (psf, cptr) ;
-						};
+						} ;
 
 					psf->has_peak = SF_TRUE ; /* Found PEAK chunk. */
 					break ;
@@ -419,7 +430,6 @@ wav_read_header	(SF_PRIVATE *psf, int *blockalign, int *framesperblock)
 						&& isprint ((marker >> 8) & 0xFF) && isprint (marker & 0xFF))
 					{	psf_binheader_readf (psf, "e4", &dword) ;
 						psf_log_printf (psf, "*** %M : %d (unknown marker)\n", marker, dword) ;
-
 						psf_binheader_readf (psf, "j", dword) ;
 						break ;
 						} ;
@@ -437,7 +447,9 @@ wav_read_header	(SF_PRIVATE *psf, int *blockalign, int *framesperblock)
 			break ;
 
 		if (psf_ftell (psf) >= psf->filelength - sizeof (dword))
+		{	psf_log_printf (psf, "End\n") ;
 			break ;
+			} ;
 
 		if (psf->logindex >= sizeof (psf->logbuffer) - 2)
 			return SFE_LOG_OVERRUN ;
@@ -503,7 +515,7 @@ wav_read_header	(SF_PRIVATE *psf, int *blockalign, int *framesperblock)
 					break ;
 
 		case WAVE_FORMAT_IEEE_FLOAT :
-					psf->sf.format  = SF_FORMAT_WAV ;
+					psf->sf.format = SF_FORMAT_WAV ;
 					psf->sf.format |= (psf->bytewidth == 8) ? SF_FORMAT_DOUBLE : SF_FORMAT_FLOAT ;
 					break ;
 
@@ -521,17 +533,18 @@ wav_write_header (SF_PRIVATE *psf, int calc_length)
 	current = psf_ftell (psf) ;
 
 	if (calc_length)
-	{	psf_fseek (psf, 0, SEEK_END) ;
-		psf->filelength = psf_ftell (psf) ;
-		psf_fseek (psf, 0, SEEK_SET) ;
+	{	psf->filelength = psf_get_filelen (psf) ;
 
 		psf->datalength = psf->filelength - psf->dataoffset ;
+
 		if (psf->dataend)
 			psf->datalength -= psf->filelength - psf->dataend ;
 
-		psf->sf.frames = psf->datalength / (psf->bytewidth * psf->sf.channels) ;
+		if (psf->bytewidth > 0)
+			psf->sf.frames = psf->datalength / (psf->bytewidth * psf->sf.channels) ;
 		} ;
 
+
 	/* Reset the current header length to zero. */
 	psf->header [0] = 0 ;
 	psf->headindex = 0 ;
@@ -604,11 +617,11 @@ wav_write_header (SF_PRIVATE *psf, int calc_length)
 					break ;
 
 		case SF_FORMAT_IMA_ADPCM :
-					{	int  blockalign, framesperblock, bytespersec ;
+					{	int blockalign, framesperblock, bytespersec ;
 
-						blockalign      = wav_w64_srate2blocksize (psf->sf.samplerate * psf->sf.channels) ;
-						framesperblock = 2 * (blockalign - 4 * psf->sf.channels) / psf->sf.channels + 1 ;
-						bytespersec     = (psf->sf.samplerate * blockalign) / framesperblock ;
+						blockalign		= wav_w64_srate2blocksize (psf->sf.samplerate * psf->sf.channels) ;
+						framesperblock	= 2 * (blockalign - 4 * psf->sf.channels) / psf->sf.channels + 1 ;
+						bytespersec		= (psf->sf.samplerate * blockalign) / framesperblock ;
 
 						/* fmt chunk. */
 						fmt_size = 2 + 2 + 4 + 4 + 2 + 2 + 2 + 2 ;
@@ -625,15 +638,15 @@ wav_write_header (SF_PRIVATE *psf, int calc_length)
 					break ;
 
 		case SF_FORMAT_MS_ADPCM :
-					{	int  blockalign, framesperblock, bytespersec, extrabytes ;
+					{	int	blockalign, framesperblock, bytespersec, extrabytes ;
 
-						blockalign      = wav_w64_srate2blocksize (psf->sf.samplerate * psf->sf.channels) ;
-						framesperblock = 2 + 2 * (blockalign - 7 * psf->sf.channels) / psf->sf.channels ;
-						bytespersec     = (psf->sf.samplerate * blockalign) / framesperblock ;
+						blockalign		= wav_w64_srate2blocksize (psf->sf.samplerate * psf->sf.channels) ;
+						framesperblock	= 2 + 2 * (blockalign - 7 * psf->sf.channels) / psf->sf.channels ;
+						bytespersec		= (psf->sf.samplerate * blockalign) / framesperblock ;
 
 						/* fmt chunk. */
-						extrabytes = 2 + 2 + MSADPCM_ADAPT_COEFF_COUNT * (2 + 2) ;
-						fmt_size   = 2 + 2 + 4 + 4 + 2 + 2 + 2 + extrabytes ;
+						extrabytes	= 2 + 2 + MSADPCM_ADAPT_COEFF_COUNT * (2 + 2) ;
+						fmt_size	= 2 + 2 + 4 + 4 + 2 + 2 + 2 + extrabytes ;
 
 						/* fmt : size, WAV format type, channels. */
 						psf_binheader_writef (psf, "e422", fmt_size, WAVE_FORMAT_MS_ADPCM, psf->sf.channels) ;
@@ -651,11 +664,11 @@ wav_write_header (SF_PRIVATE *psf, int calc_length)
 					break ;
 
 		case SF_FORMAT_GSM610 :
-					{	int  blockalign, framesperblock, bytespersec ;
+					{	int	blockalign, framesperblock, bytespersec ;
 
-						blockalign      = WAV_W64_GSM610_BLOCKSIZE ;
-						framesperblock = WAV_W64_GSM610_SAMPLES ;
-						bytespersec     = (psf->sf.samplerate * blockalign) / framesperblock ;
+						blockalign		= WAV_W64_GSM610_BLOCKSIZE ;
+						framesperblock	= WAV_W64_GSM610_SAMPLES ;
+						bytespersec		= (psf->sf.samplerate * blockalign) / framesperblock ;
 
 						/* fmt chunk. */
 						fmt_size = 2 + 2 + 4 + 4 + 2 + 2 + 2 + 2 ;
@@ -687,7 +700,7 @@ wav_write_header (SF_PRIVATE *psf, int calc_length)
 			sizeof (psf->peak) - sizeof (psf->peak.peak) + psf->sf.channels * sizeof (PEAK_POS)) ;
 		psf_binheader_writef (psf, "e44", 1, time (NULL)) ;
 		for (k = 0 ; k < psf->sf.channels ; k++)
-			psf_binheader_writef (psf, "ef4", psf->peak.peak[k].value, psf->peak.peak[k].position) ;
+			psf_binheader_writef (psf, "ef4", psf->peak.peak [k].value, psf->peak.peak [k].position) ;
 		} ;
 
 	psf_binheader_writef (psf, "etm8", data_MARKER, psf->datalength) ;
@@ -712,7 +725,8 @@ wav_write_tailer (SF_PRIVATE *psf)
 	/* Reset the current header buffer length to zero. */
 	psf->header [0] = 0 ;
 	psf->headindex = 0 ;
-	psf_fseek (psf, 0, SEEK_END) ;
+
+	psf->dataend = psf_fseek (psf, 0, SEEK_END) ;
 
 	/* Add a PEAK chunk if requested. */
 	if (psf->has_peak && psf->peak_loc == SF_PEAK_END)
@@ -720,19 +734,9 @@ wav_write_tailer (SF_PRIVATE *psf)
 			sizeof (psf->peak) - sizeof (psf->peak.peak) + psf->sf.channels * sizeof (PEAK_POS)) ;
 		psf_binheader_writef (psf, "e44", 1, time (NULL)) ;
 		for (k = 0 ; k < psf->sf.channels ; k++)
-			psf_binheader_writef (psf, "ef4", psf->peak.peak[k].value, psf->peak.peak[k].position) ; /* XXXXX */
+			psf_binheader_writef (psf, "ef4", psf->peak.peak [k].value, psf->peak.peak [k].position) ;
 		} ;
 
-/*-	if (psf->add_test_tailer)
-	{	int namelen ;
-		/+* Add INFO chunk. *+/
-		namelen = strlen (PACKAGE "-" VERSION) ;
-		namelen = (namelen & 1) ? namelen + 1 : namelen ; /+* Length must be even. *+/
-
-		psf_binheader_writef (psf, "em4mm", LIST_MARKER, namelen + 8, INFO_MARKER, ISFT_MARKER) ;
-		psf_binheader_writef (psf, "e4b", namelen, PACKAGE "-" VERSION "\0", namelen) ;
-		} ;
--*/
 	if (psf->str_flags & SF_STR_LOCATE_END)
 		wav_write_strings (psf, SF_STR_LOCATE_END) ;
 
@@ -786,30 +790,18 @@ wav_write_strings (SF_PRIVATE *psf, int location)
 
 	saved_head_index = psf->headindex ;
 	psf->headindex = prev_head_index ;
-	psf_binheader_writef (psf, "e4", saved_head_index - prev_head_index) ;
+	psf_binheader_writef (psf, "e4", saved_head_index - prev_head_index - 4) ;
 	psf->headindex = saved_head_index ;
 
-} /* wave_write_strings */
+} /* wav_write_strings */
 
 static int
-wav_close (SF_PRIVATE  *psf)
+wav_close (SF_PRIVATE *psf)
 {
 	if (psf->mode == SFM_WRITE || psf->mode == SFM_RDWR)
-	{	/*  Now we know for certain the length of the file we can
-		 *  re-write correct values for the RIFF and data chunks.
-		 */
-		psf_fseek (psf, 0, SEEK_END) ;
-		psf->dataend = psf_ftell (psf) ;
-		wav_write_tailer (psf) ;
+	{	wav_write_tailer (psf) ;
 
-		psf_fseek (psf, 0, SEEK_END) ;
-		psf->filelength = psf_ftell (psf) ;
-		psf_fseek (psf, 0, SEEK_SET) ;
-
-		psf->datalength = psf->filelength - psf->dataoffset - (psf->filelength - psf->dataend) ;
- 		psf->sf.frames = psf->datalength / (psf->bytewidth * psf->sf.channels) ;
-
-		wav_write_header (psf, SF_FALSE) ;
+		wav_write_header (psf, SF_TRUE) ;
 		} ;
 
 	return 0 ;
@@ -819,15 +811,12 @@ static int
 wav_command (SF_PRIVATE *psf, int command, void *data, int datasize)
 {
 	/* Avoid compiler warnings. */
+	psf = psf ;
 	data = data ;
 	datasize = datasize ;
 
 	switch (command)
-	{	case SFC_TEST_ADD_TRAILING_DATA :
-			psf->add_test_tailer = SF_TRUE ;
-			break ;
-
-		default : break ;
+	{	default : break ;
 		} ;
 
 	return 0 ;
@@ -836,6 +825,7 @@ wav_command (SF_PRIVATE *psf, int command, void *data, int datasize)
 static int
 wav_subchunk_parse (SF_PRIVATE *psf, int chunk)
 {	sf_count_t	current_pos ;
+	char		*cptr ;
 	int 		dword, bytesread, length ;
 
 	current_pos = psf_fseek (psf, 0, SEEK_CUR) ;
@@ -884,10 +874,12 @@ wav_subchunk_parse (SF_PRIVATE *psf, int chunk)
 					{	psf_log_printf (psf, "  *** %M : %d (too big)\n", chunk, dword) ;
 						return SFE_INTERNAL ;
 						} ;
-					psf_binheader_readf (psf, "b", psf->buffer, dword) ;
+
+					cptr = (char*) psf->buffer ;
+					psf_binheader_readf (psf, "b", cptr, dword) ;
 					bytesread += dword ;
-					psf->buffer [dword - 1] = 0 ;
-					psf_log_printf (psf, "    %M : %s\n", chunk, psf->buffer) ;
+					cptr [dword - 1] = 0 ;
+					psf_log_printf (psf, "    %M : %s\n", chunk, cptr) ;
 					break ;
 
 			case labl_MARKER :
@@ -900,10 +892,12 @@ wav_subchunk_parse (SF_PRIVATE *psf, int chunk)
 						{	psf_log_printf (psf, "  *** %M : %d (too big)\n", chunk, dword) ;
 							return SFE_INTERNAL ;
 							} ;
-						psf_binheader_readf (psf, "b", psf->buffer, dword) ;
+
+						cptr = (char*) psf->buffer ;
+						psf_binheader_readf (psf, "b", cptr, dword) ;
 						bytesread += dword ;
-						psf->buffer [dword - 1] = 0 ;
-						psf_log_printf (psf, "    %M : %d : %s\n", chunk, mark_id, psf->buffer) ;
+						cptr [dword - 1] = 0 ;
+						psf_log_printf (psf, "    %M : %d : %s\n", chunk, mark_id, cptr) ;
 						} ;
 					break ;
 
@@ -955,6 +949,11 @@ wav_subchunk_parse (SF_PRIVATE *psf, int chunk)
 			return SFE_LOG_OVERRUN ;
 		} ;
 
+	current_pos = psf_fseek (psf, 0, SEEK_CUR) - current_pos ;
+
+	if (current_pos - 4 != length)
+		psf_log_printf (psf, "**** Bad chunk length %d sbould be %D\n", length, current_pos - 4) ;
+
 	return 0 ;
 } /* wav_subchunk_parse */
 
@@ -1077,14 +1076,14 @@ wav_read_acid_chunk (SF_PRIVATE *psf, unsigned int chunklen)
 {	unsigned int bytesread = 0 ;
 	int	beats ;
 	short rootnote, q1, meter_denom, meter_numer ;
-	float q2, tempo ;
+	float q2, q3, tempo ;
 
 	chunklen += (chunklen & 1) ;
 
-	bytesread += psf_binheader_readf (psf, "e22f", &rootnote, &q1, &q2) ;
+	bytesread += psf_binheader_readf (psf, "e224f", &rootnote, &q1, &q2, &q3) ;
 	LSF_SNPRINTF ((char*) psf->buffer, sizeof (psf->buffer), "%f", q2) ;
-	psf_log_printf (psf, "  Root note : %d\n  ????      : %d\n  ????      : %s\n",
-				rootnote, q1, psf->buffer) ;
+	psf_log_printf (psf, "  Root note : %d\n  ????      : %d\n  ????      : %s\n  ????      : %d\n",
+				rootnote, q1, psf->buffer, q3) ;
 
 	bytesread += psf_binheader_readf (psf, "e422f", &beats, &meter_denom, &meter_numer, &tempo) ;
 	LSF_SNPRINTF ((char*) psf->buffer, sizeof (psf->buffer), "%f", tempo) ;
