@@ -126,13 +126,7 @@ xi_open	(SF_PRIVATE *psf)
 static int
 xi_close	(SF_PRIVATE  *psf)
 {
-	/* The compete header for PVF files can be written when the
-	** file is opened so nothing needs to be done here.
-	*/
-
-	if (psf->fdata)
-		free (psf->fdata) ;
-	psf->fdata = NULL ;
+	psf = psf ;
 
 	return 0 ;
 } /* xi_close */
