@@ -1,18 +1,18 @@
 /*
 ** Copyright (C) 2001-2003 Erik de Castro Lopo <erikd@zip.com.au>
-**  
+**
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
-** 
+**
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
-** 
+**
 ** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software 
+** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
@@ -66,7 +66,7 @@ static void	permission_test (char *filename, int typemajor) ;
 static	short	data_out [BUFFER_LEN] ;
 static	short	data_in  [BUFFER_LEN] ;
 
-int		
+int
 main (int argc, char *argv[])
 {	int		do_all = 0 ;
 	int		test_count = 0 ;
@@ -81,7 +81,7 @@ main (int argc, char *argv[])
 		} ;
 
 	do_all=!strcmp (argv [1], "all");
-		
+
 	if (do_all || ! strcmp (argv [1], "wav"))
 	{	update_header_test ("header.wav", SF_FORMAT_WAV) ;
 		zero_data_test ("zerolen.wav", SF_FORMAT_WAV) ;
@@ -173,11 +173,19 @@ main (int argc, char *argv[])
 	if (do_all || ! strcmp (argv [1], "pvf"))
 	{	update_header_test ("header.pvf", SF_FORMAT_PVF) ;
 		zero_data_test ("zerolen.pvf", SF_FORMAT_PVF) ;
-		filesystem_full_test (SF_FORMAT_MAT5) ;
+		filesystem_full_test (SF_FORMAT_PVF) ;
 		permission_test ("readonly.pvf", SF_FORMAT_PVF) ;
 		test_count++ ;
 		} ;
 
+	if (do_all || ! strcmp (argv [1], "htk"))
+	{	update_header_test ("header.htk", SF_FORMAT_HTK) ;
+		zero_data_test ("zerolen.htk", SF_FORMAT_HTK) ;
+		filesystem_full_test (SF_FORMAT_HTK) ;
+		permission_test ("readonly.htk", SF_FORMAT_HTK) ;
+		test_count++ ;
+		} ;
+
 	if (test_count == 0)
 	{	printf ("Mono : ************************************\n") ;
 		printf ("Mono : *  No '%s' test defined.\n", argv [1]) ;
@@ -191,16 +199,16 @@ main (int argc, char *argv[])
 
 /*============================================================================================
 **	Here are the test functions.
-*/ 
+*/
 
-static void	
+static void
 update_header_test (char *filename, int typemajor)
 {	SNDFILE		*outfile, *infile ;
 	SF_INFO		sfinfo ;
 	int			k, frames ;
 
 	print_test_name ("update_header_test", filename) ;
-	
+
 	sfinfo.samplerate  = 44100 ;
 	sfinfo.format 	   = (typemajor | SF_FORMAT_PCM_16) ;
 	sfinfo.channels    = 1 ;
@@ -214,13 +222,16 @@ update_header_test (char *filename, int typemajor)
 		data_out [k] = k + 1 ;
 	test_write_short_or_die (outfile, 0, data_out, BUFFER_LEN, __LINE__) ;
 
-	infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
-	sf_close (infile) ;
+	if (typemajor != SF_FORMAT_HTK)
+	{	/* The HTK header is not correct when the file is firstw written. */
+		infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+		sf_close (infile) ;
+		} ;
 
 	sf_command (outfile, SFC_UPDATE_HEADER_NOW, NULL, 0) ;
 
 	/* Open file and check log buffer for an error. If header update failed
-	** the the log buffer will contain errors. 
+	** the the log buffer will contain errors.
 	*/
 	infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
 	check_log_buffer_or_die (infile) ;
@@ -237,7 +248,7 @@ update_header_test (char *filename, int typemajor)
 			printf ("Error : line %d\n", __LINE__) ;
 
 	sf_close (infile) ;
-	
+
 	/* Set auto update on. */
 	sf_command (outfile, SFC_SET_UPDATE_HEADER_AUTO, NULL, SF_TRUE) ;
 
@@ -249,7 +260,7 @@ update_header_test (char *filename, int typemajor)
 	/* Open file again and make sure no errors in log buffer. */
 	infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
 	check_log_buffer_or_die (infile) ;
-	
+
 	if (abs (2 * BUFFER_LEN - sfinfo.frames) > 1)
 	{	printf ("\n\nLine %d : Incorrect sample count (%ld should be %d)\n", __LINE__, SF_COUNT_TO_LONG (sfinfo.frames), 2 * BUFFER_LEN) ;
 		dump_log_buffer (infile) ;
@@ -257,21 +268,21 @@ update_header_test (char *filename, int typemajor)
 		} ;
 
 	sf_close (infile) ;
-	
+
 	sf_close (outfile) ;
 
 	unlink (filename) ;
 	puts ("ok") ;
 } /* update_header_test */
 
-static void	
+static void
 zero_data_test (char *filename, int typemajor)
 {	SNDFILE		*file ;
 	SF_INFO		sfinfo ;
 	int			frames ;
 
 	print_test_name ("zero_data_test", filename) ;
-	
+
 	sfinfo.samplerate  = 44100 ;
 	sfinfo.format 	   = (typemajor | SF_FORMAT_PCM_16) ;
 	sfinfo.channels    = 1 ;
@@ -280,9 +291,9 @@ zero_data_test (char *filename, int typemajor)
 	frames = BUFFER_LEN / sfinfo.channels ;
 
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
-	
+
 	sf_close (file) ;
-	
+
 	memset (&sfinfo, 0, sizeof (sfinfo)) ;
 
 	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
@@ -293,7 +304,7 @@ zero_data_test (char *filename, int typemajor)
 	puts ("ok") ;
 } /* zero_data_test */
 
-static void	
+static void
 filesystem_full_test (int typemajor)
 {	SNDFILE		*file ;
 	SF_INFO		sfinfo ;
@@ -306,14 +317,14 @@ filesystem_full_test (int typemajor)
 	/* Can't run this test on Win32 so return. */
 	return ;
 #endif
-	
+
 	print_test_name ("filesystem_full_test", filename) ;
-	
+
 	if (stat (filename, &buf) != 0)
 	{	puts ("/dev/full missing") ;
 		return ;
 		} ;
-		
+
 	if (S_ISCHR (buf.st_mode) == 0 && S_ISBLK (buf.st_mode) == 0)
 	{	puts ("/dev/full is not a device file") ;
 		return ;
@@ -325,12 +336,12 @@ filesystem_full_test (int typemajor)
 	sfinfo.frames     = 0 ;
 
 	frames = BUFFER_LEN / sfinfo.channels ;
-	
+
 	if ((file = sf_open (filename, SFM_WRITE, &sfinfo)) != NULL)
 	{	printf ("\n\nLine %d : Error, file should not have openned.\n", __LINE__ - 1) ;
 		exit (1) ;
 		} ;
-		
+
 	errorstr = sf_strerror (file) ;
 
 	if (strstr (errorstr, " space ") == NULL || strstr (errorstr, "device") == NULL)
@@ -354,43 +365,43 @@ permission_test (char *filename, int typemajor)
 	/* Can't run this test on Win32 so return. */
 	return ;
 #endif
-	
+
 	if (getuid () == 0)
-	{	/* If running as root bypass this test. 
+	{	/* If running as root bypass this test.
 		** Root is allowed to open a readonly file for write.
 		*/
 		return ;
 		} ;
-	
+
 	print_test_name ("permission_test", filename) ;
-	
+
 	if ((textfile = fopen (filename, "w")) == NULL)
 	{	printf ("\n\nLine %d : not able to open text file for write.\n", __LINE__) ;
 		exit (1) ;
 		} ;
-	
+
 	fprintf (textfile, "This is a read only file.\n") ;
 	fclose (textfile) ;
-	
+
 	if (chmod (filename, S_IRUSR | S_IRGRP))
 	{	printf ("\n\nLine %d : chmod failed", __LINE__) ;
 		fflush (stdout) ;
 		perror ("") ;
 		exit (1) ;
 		} ;
-	
+
 	sfinfo.samplerate = 44100 ;
 	sfinfo.format 	  = (typemajor | SF_FORMAT_PCM_16) ;
 	sfinfo.channels   = 1 ;
 	sfinfo.frames     = 0 ;
 
 	frames = BUFFER_LEN / sfinfo.channels ;
-	
+
 	if ((file = sf_open (filename, SFM_WRITE, &sfinfo)) != NULL)
 	{	printf ("\n\nLine %d : Error, file should not have opened.\n", __LINE__ - 1) ;
 		exit (1) ;
 		} ;
-		
+
 	errorstr = sf_strerror (file) ;
 
 	if (strstr (errorstr, "ould not open file") == NULL)
@@ -406,7 +417,7 @@ permission_test (char *filename, int typemajor)
 		} ;
 
 	unlink (filename) ;
-	
+
 	puts ("ok") ;
 } /* permission_test */
 
