@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 1999-2003 Erik de Castro Lopo <erikd@zip.com.au>
+** Copyright (C) 1999-2002 Erik de Castro Lopo <erikd@zip.com.au>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -43,11 +43,6 @@ static void	pcm_test_float	(char *str, int filetype, int long_file_ok) ;
 static void	pcm_test_double	(char *str, int filetype, int long_file_ok) ;
 
 
-enum
-{	FALSE = 0,
-	TRUE  = 1
-} ;
-
 static	double	orig_data [DATA_LENGTH] ;
 static	double	test_data [DATA_LENGTH] ;
 
@@ -76,167 +71,173 @@ main (int argc, char **argv)
 	do_all = !strcmp (argv [1], "all");
 
 	if (do_all || ! strcmp (argv [1], "wav"))
-	{	pcm_test_char 	("char.wav"  , SF_FORMAT_WAV | SF_FORMAT_PCM_U8, FALSE) ;
-		pcm_test_short	("short.wav" , SF_FORMAT_WAV | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_24bit	("24bit.wav" , SF_FORMAT_WAV | SF_FORMAT_PCM_24, FALSE) ;
-		pcm_test_int	("int.wav"   , SF_FORMAT_WAV | SF_FORMAT_PCM_32, FALSE) ;
-		pcm_test_float	("float.wav" , SF_FORMAT_WAV | SF_FORMAT_FLOAT , FALSE) ;
-		pcm_test_double	("double.wav", SF_FORMAT_WAV | SF_FORMAT_DOUBLE, FALSE) ;
+	{	pcm_test_char 	("char.wav"  , SF_FORMAT_WAV | SF_FORMAT_PCM_U8, SF_FALSE) ;
+		pcm_test_short	("short.wav" , SF_FORMAT_WAV | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_24bit	("24bit.wav" , SF_FORMAT_WAV | SF_FORMAT_PCM_24, SF_FALSE) ;
+		pcm_test_int	("int.wav"   , SF_FORMAT_WAV | SF_FORMAT_PCM_32, SF_FALSE) ;
+		pcm_test_float	("float.wav" , SF_FORMAT_WAV | SF_FORMAT_FLOAT , SF_FALSE) ;
+		pcm_test_double	("double.wav", SF_FORMAT_WAV | SF_FORMAT_DOUBLE, SF_FALSE) ;
 		test_count++ ;
 		} ;
 
 	if (do_all || ! strcmp (argv [1], "aiff"))
-	{	pcm_test_char	("char_u8.aiff", SF_FORMAT_AIFF | SF_FORMAT_PCM_U8, FALSE) ;
-		pcm_test_char	("char_s8.aiff", SF_FORMAT_AIFF | SF_FORMAT_PCM_S8, FALSE) ;
-		pcm_test_short	("short.aiff"  , SF_FORMAT_AIFF | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_24bit	("24bit.aiff"  , SF_FORMAT_AIFF | SF_FORMAT_PCM_24, FALSE) ;
-		pcm_test_int	("int.aiff"    , SF_FORMAT_AIFF | SF_FORMAT_PCM_32, FALSE) ;
+	{	pcm_test_char	("char_u8.aiff", SF_FORMAT_AIFF | SF_FORMAT_PCM_U8, SF_FALSE) ;
+		pcm_test_char	("char_s8.aiff", SF_FORMAT_AIFF | SF_FORMAT_PCM_S8, SF_FALSE) ;
+		pcm_test_short	("short.aiff"  , SF_FORMAT_AIFF | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_24bit	("24bit.aiff"  , SF_FORMAT_AIFF | SF_FORMAT_PCM_24, SF_FALSE) ;
+		pcm_test_int	("int.aiff"    , SF_FORMAT_AIFF | SF_FORMAT_PCM_32, SF_FALSE) ;
 
-		pcm_test_short	("short_sowt.aifc", SF_ENDIAN_LITTLE | SF_FORMAT_AIFF | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_24bit	("24bit_sowt.aifc", SF_ENDIAN_LITTLE | SF_FORMAT_AIFF | SF_FORMAT_PCM_24, FALSE) ;
-		pcm_test_int	("int_sowt.aifc"  , SF_ENDIAN_LITTLE | SF_FORMAT_AIFF | SF_FORMAT_PCM_32, FALSE) ;
+		pcm_test_short	("short_sowt.aifc", SF_ENDIAN_LITTLE | SF_FORMAT_AIFF | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_24bit	("24bit_sowt.aifc", SF_ENDIAN_LITTLE | SF_FORMAT_AIFF | SF_FORMAT_PCM_24, SF_FALSE) ;
+		pcm_test_int	("int_sowt.aifc"  , SF_ENDIAN_LITTLE | SF_FORMAT_AIFF | SF_FORMAT_PCM_32, SF_FALSE) ;
 
-		pcm_test_short	("short_twos.aifc", SF_ENDIAN_BIG | SF_FORMAT_AIFF | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_24bit	("24bit_twos.aifc", SF_ENDIAN_BIG | SF_FORMAT_AIFF | SF_FORMAT_PCM_24, FALSE) ;
-		pcm_test_int	("int_twos.aifc"  , SF_ENDIAN_BIG | SF_FORMAT_AIFF | SF_FORMAT_PCM_32, FALSE) ;
+		pcm_test_short	("short_twos.aifc", SF_ENDIAN_BIG | SF_FORMAT_AIFF | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_24bit	("24bit_twos.aifc", SF_ENDIAN_BIG | SF_FORMAT_AIFF | SF_FORMAT_PCM_24, SF_FALSE) ;
+		pcm_test_int	("int_twos.aifc"  , SF_ENDIAN_BIG | SF_FORMAT_AIFF | SF_FORMAT_PCM_32, SF_FALSE) ;
 
-		pcm_test_short	("dwvw16.aifc", SF_FORMAT_AIFF | SF_FORMAT_DWVW_16, TRUE) ;
-		pcm_test_24bit	("dwvw24.aifc", SF_FORMAT_AIFF | SF_FORMAT_DWVW_24, TRUE) ;
+		pcm_test_short	("dwvw16.aifc", SF_FORMAT_AIFF | SF_FORMAT_DWVW_16, SF_TRUE) ;
+		pcm_test_24bit	("dwvw24.aifc", SF_FORMAT_AIFF | SF_FORMAT_DWVW_24, SF_TRUE) ;
 
-		pcm_test_float	("float.aifc" , SF_FORMAT_AIFF | SF_FORMAT_FLOAT , FALSE) ;
-		pcm_test_double	("double.aifc", SF_FORMAT_AIFF | SF_FORMAT_DOUBLE, FALSE) ;
+		pcm_test_float	("float.aifc" , SF_FORMAT_AIFF | SF_FORMAT_FLOAT , SF_FALSE) ;
+		pcm_test_double	("double.aifc", SF_FORMAT_AIFF | SF_FORMAT_DOUBLE, SF_FALSE) ;
 
 		test_count++ ;
 		} ;
 
 	if (do_all || ! strcmp (argv [1], "au"))
-	{	pcm_test_char	("char.au"  , SF_FORMAT_AU | SF_FORMAT_PCM_S8, FALSE) ;
-		pcm_test_short	("short.au" , SF_FORMAT_AU | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_24bit	("24bit.au" , SF_FORMAT_AU | SF_FORMAT_PCM_24, FALSE) ;
-		pcm_test_int	("int.au"   , SF_FORMAT_AU | SF_FORMAT_PCM_32, FALSE) ;
-		pcm_test_float	("float.au" , SF_FORMAT_AU | SF_FORMAT_FLOAT , FALSE) ;
-		pcm_test_double	("double.au", SF_FORMAT_AU | SF_FORMAT_DOUBLE, FALSE) ;
+	{	pcm_test_char	("char.au"  , SF_FORMAT_AU | SF_FORMAT_PCM_S8, SF_FALSE) ;
+		pcm_test_short	("short.au" , SF_FORMAT_AU | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_24bit	("24bit.au" , SF_FORMAT_AU | SF_FORMAT_PCM_24, SF_FALSE) ;
+		pcm_test_int	("int.au"   , SF_FORMAT_AU | SF_FORMAT_PCM_32, SF_FALSE) ;
+		pcm_test_float	("float.au" , SF_FORMAT_AU | SF_FORMAT_FLOAT , SF_FALSE) ;
+		pcm_test_double	("double.au", SF_FORMAT_AU | SF_FORMAT_DOUBLE, SF_FALSE) ;
 
-		pcm_test_char	("char_le.au"  , SF_ENDIAN_LITTLE | SF_FORMAT_AU | SF_FORMAT_PCM_S8, FALSE) ;
-		pcm_test_short	("short_le.au" , SF_ENDIAN_LITTLE | SF_FORMAT_AU | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_24bit	("24bit_le.au" , SF_ENDIAN_LITTLE | SF_FORMAT_AU | SF_FORMAT_PCM_24, FALSE) ;
-		pcm_test_int	("int_le.au"   , SF_ENDIAN_LITTLE | SF_FORMAT_AU | SF_FORMAT_PCM_32, FALSE) ;
-		pcm_test_float	("float_le.au" , SF_ENDIAN_LITTLE | SF_FORMAT_AU | SF_FORMAT_FLOAT , FALSE) ;
-		pcm_test_double	("double_le.au", SF_ENDIAN_LITTLE | SF_FORMAT_AU | SF_FORMAT_DOUBLE, FALSE) ;
+		pcm_test_char	("char_le.au"  , SF_ENDIAN_LITTLE | SF_FORMAT_AU | SF_FORMAT_PCM_S8, SF_FALSE) ;
+		pcm_test_short	("short_le.au" , SF_ENDIAN_LITTLE | SF_FORMAT_AU | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_24bit	("24bit_le.au" , SF_ENDIAN_LITTLE | SF_FORMAT_AU | SF_FORMAT_PCM_24, SF_FALSE) ;
+		pcm_test_int	("int_le.au"   , SF_ENDIAN_LITTLE | SF_FORMAT_AU | SF_FORMAT_PCM_32, SF_FALSE) ;
+		pcm_test_float	("float_le.au" , SF_ENDIAN_LITTLE | SF_FORMAT_AU | SF_FORMAT_FLOAT , SF_FALSE) ;
+		pcm_test_double	("double_le.au", SF_ENDIAN_LITTLE | SF_FORMAT_AU | SF_FORMAT_DOUBLE, SF_FALSE) ;
 
 		test_count++ ;
 		} ;
 
 	if (do_all || ! strcmp (argv [1], "raw"))
-	{	pcm_test_char	("char_s8.raw", SF_FORMAT_RAW | SF_FORMAT_PCM_S8, FALSE) ;
-		pcm_test_char	("char_u8.raw", SF_FORMAT_RAW | SF_FORMAT_PCM_U8, FALSE) ;
+	{	pcm_test_char	("char_s8.raw", SF_FORMAT_RAW | SF_FORMAT_PCM_S8, SF_FALSE) ;
+		pcm_test_char	("char_u8.raw", SF_FORMAT_RAW | SF_FORMAT_PCM_U8, SF_FALSE) ;
 
-		pcm_test_short	("short_le.raw", SF_ENDIAN_LITTLE | SF_FORMAT_RAW | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_short	("short_be.raw", SF_ENDIAN_BIG    | SF_FORMAT_RAW | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_24bit	("24bit_le.raw", SF_ENDIAN_LITTLE | SF_FORMAT_RAW | SF_FORMAT_PCM_24, FALSE) ;
-		pcm_test_24bit	("24bit_be.raw", SF_ENDIAN_BIG    | SF_FORMAT_RAW | SF_FORMAT_PCM_24, FALSE) ;
-		pcm_test_int	("int_le.raw"  , SF_ENDIAN_LITTLE | SF_FORMAT_RAW | SF_FORMAT_PCM_32, FALSE) ;
-		pcm_test_int	("int_be.raw"  , SF_ENDIAN_BIG    | SF_FORMAT_RAW | SF_FORMAT_PCM_32, FALSE) ;
+		pcm_test_short	("short_le.raw", SF_ENDIAN_LITTLE | SF_FORMAT_RAW | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_short	("short_be.raw", SF_ENDIAN_BIG    | SF_FORMAT_RAW | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_24bit	("24bit_le.raw", SF_ENDIAN_LITTLE | SF_FORMAT_RAW | SF_FORMAT_PCM_24, SF_FALSE) ;
+		pcm_test_24bit	("24bit_be.raw", SF_ENDIAN_BIG    | SF_FORMAT_RAW | SF_FORMAT_PCM_24, SF_FALSE) ;
+		pcm_test_int	("int_le.raw"  , SF_ENDIAN_LITTLE | SF_FORMAT_RAW | SF_FORMAT_PCM_32, SF_FALSE) ;
+		pcm_test_int	("int_be.raw"  , SF_ENDIAN_BIG    | SF_FORMAT_RAW | SF_FORMAT_PCM_32, SF_FALSE) ;
 
-		pcm_test_float	("float_le.raw", SF_ENDIAN_LITTLE | SF_FORMAT_RAW | SF_FORMAT_FLOAT , FALSE) ;
-		pcm_test_float	("float_be.raw", SF_ENDIAN_BIG    | SF_FORMAT_RAW | SF_FORMAT_FLOAT , FALSE) ;
+		pcm_test_float	("float_le.raw", SF_ENDIAN_LITTLE | SF_FORMAT_RAW | SF_FORMAT_FLOAT , SF_FALSE) ;
+		pcm_test_float	("float_be.raw", SF_ENDIAN_BIG    | SF_FORMAT_RAW | SF_FORMAT_FLOAT , SF_FALSE) ;
 
-		pcm_test_double	("double_le.raw", SF_ENDIAN_LITTLE | SF_FORMAT_RAW | SF_FORMAT_DOUBLE, FALSE) ;
-		pcm_test_double	("double_be.raw", SF_ENDIAN_BIG    | SF_FORMAT_RAW | SF_FORMAT_DOUBLE, FALSE) ;
+		pcm_test_double	("double_le.raw", SF_ENDIAN_LITTLE | SF_FORMAT_RAW | SF_FORMAT_DOUBLE, SF_FALSE) ;
+		pcm_test_double	("double_be.raw", SF_ENDIAN_BIG    | SF_FORMAT_RAW | SF_FORMAT_DOUBLE, SF_FALSE) ;
 
 		test_count++ ;
 		} ;
 
 	if (do_all || ! strcmp (argv [1], "paf"))
-	{	pcm_test_char	("char_le.paf", SF_ENDIAN_LITTLE | SF_FORMAT_PAF | SF_FORMAT_PCM_S8, FALSE) ;
-		pcm_test_char	("char_be.paf", SF_ENDIAN_BIG    | SF_FORMAT_PAF | SF_FORMAT_PCM_S8, FALSE) ;
-		pcm_test_short	("short_le.paf", SF_ENDIAN_LITTLE | SF_FORMAT_PAF | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_short	("short_be.paf", SF_ENDIAN_BIG    | SF_FORMAT_PAF | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_24bit	("24bit_le.paf", SF_ENDIAN_LITTLE | SF_FORMAT_PAF | SF_FORMAT_PCM_24, TRUE) ;
-		pcm_test_24bit	("24bit_be.paf", SF_ENDIAN_BIG    | SF_FORMAT_PAF | SF_FORMAT_PCM_24, TRUE) ;
+	{	pcm_test_char	("char_le.paf", SF_ENDIAN_LITTLE | SF_FORMAT_PAF | SF_FORMAT_PCM_S8, SF_FALSE) ;
+		pcm_test_char	("char_be.paf", SF_ENDIAN_BIG    | SF_FORMAT_PAF | SF_FORMAT_PCM_S8, SF_FALSE) ;
+		pcm_test_short	("short_le.paf", SF_ENDIAN_LITTLE | SF_FORMAT_PAF | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_short	("short_be.paf", SF_ENDIAN_BIG    | SF_FORMAT_PAF | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_24bit	("24bit_le.paf", SF_ENDIAN_LITTLE | SF_FORMAT_PAF | SF_FORMAT_PCM_24, SF_TRUE) ;
+		pcm_test_24bit	("24bit_be.paf", SF_ENDIAN_BIG    | SF_FORMAT_PAF | SF_FORMAT_PCM_24, SF_TRUE) ;
 
 		test_count++ ;
 		} ;
 
 	if (do_all || ! strcmp (argv [1], "svx"))
-	{	pcm_test_char	("char.svx" , SF_FORMAT_SVX | SF_FORMAT_PCM_S8, FALSE) ;
-		pcm_test_short	("short.svx", SF_FORMAT_SVX | SF_FORMAT_PCM_16, FALSE) ;
+	{	pcm_test_char	("char.svx" , SF_FORMAT_SVX | SF_FORMAT_PCM_S8, SF_FALSE) ;
+		pcm_test_short	("short.svx", SF_FORMAT_SVX | SF_FORMAT_PCM_16, SF_FALSE) ;
 
 		test_count++ ;
 		} ;
 
 	if (do_all || ! strcmp (argv [1], "nist"))
-	{	pcm_test_short	("short_le.nist", SF_ENDIAN_LITTLE | SF_FORMAT_NIST | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_short	("short_be.nist", SF_ENDIAN_BIG    | SF_FORMAT_NIST | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_24bit	("24bit_le.nist", SF_ENDIAN_LITTLE | SF_FORMAT_NIST | SF_FORMAT_PCM_24, FALSE) ;
-		pcm_test_24bit	("24bit_be.nist", SF_ENDIAN_BIG    | SF_FORMAT_NIST | SF_FORMAT_PCM_24, FALSE) ;
-		pcm_test_int	("int_le.nist"  , SF_ENDIAN_LITTLE | SF_FORMAT_NIST | SF_FORMAT_PCM_32, FALSE) ;
-		pcm_test_int 	("int_be.nist"  , SF_ENDIAN_BIG    | SF_FORMAT_NIST | SF_FORMAT_PCM_32, FALSE) ;
+	{	pcm_test_short	("short_le.nist", SF_ENDIAN_LITTLE | SF_FORMAT_NIST | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_short	("short_be.nist", SF_ENDIAN_BIG    | SF_FORMAT_NIST | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_24bit	("24bit_le.nist", SF_ENDIAN_LITTLE | SF_FORMAT_NIST | SF_FORMAT_PCM_24, SF_FALSE) ;
+		pcm_test_24bit	("24bit_be.nist", SF_ENDIAN_BIG    | SF_FORMAT_NIST | SF_FORMAT_PCM_24, SF_FALSE) ;
+		pcm_test_int	("int_le.nist"  , SF_ENDIAN_LITTLE | SF_FORMAT_NIST | SF_FORMAT_PCM_32, SF_FALSE) ;
+		pcm_test_int 	("int_be.nist"  , SF_ENDIAN_BIG    | SF_FORMAT_NIST | SF_FORMAT_PCM_32, SF_FALSE) ;
 
 		test_count++ ;
 		} ;
 
 	if (do_all || ! strcmp (argv [1], "ircam"))
-	{	pcm_test_short	("short_be.ircam", SF_ENDIAN_BIG    | SF_FORMAT_IRCAM | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_short	("short_le.ircam", SF_ENDIAN_LITTLE | SF_FORMAT_IRCAM | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_int	("int_be.ircam"  , SF_ENDIAN_BIG    | SF_FORMAT_IRCAM | SF_FORMAT_PCM_32, FALSE) ;
-		pcm_test_int 	("int_le.ircam"  , SF_ENDIAN_LITTLE | SF_FORMAT_IRCAM | SF_FORMAT_PCM_32, FALSE) ;
-		pcm_test_float	("float_be.ircam", SF_ENDIAN_BIG    | SF_FORMAT_IRCAM | SF_FORMAT_FLOAT , FALSE) ;
-		pcm_test_float	("float_le.ircam", SF_ENDIAN_LITTLE | SF_FORMAT_IRCAM | SF_FORMAT_FLOAT , FALSE) ;
+	{	pcm_test_short	("short_be.ircam", SF_ENDIAN_BIG    | SF_FORMAT_IRCAM | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_short	("short_le.ircam", SF_ENDIAN_LITTLE | SF_FORMAT_IRCAM | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_int	("int_be.ircam"  , SF_ENDIAN_BIG    | SF_FORMAT_IRCAM | SF_FORMAT_PCM_32, SF_FALSE) ;
+		pcm_test_int 	("int_le.ircam"  , SF_ENDIAN_LITTLE | SF_FORMAT_IRCAM | SF_FORMAT_PCM_32, SF_FALSE) ;
+		pcm_test_float	("float_be.ircam", SF_ENDIAN_BIG    | SF_FORMAT_IRCAM | SF_FORMAT_FLOAT , SF_FALSE) ;
+		pcm_test_float	("float_le.ircam", SF_ENDIAN_LITTLE | SF_FORMAT_IRCAM | SF_FORMAT_FLOAT , SF_FALSE) ;
 
 		test_count++ ;
 		} ;
 
 	if (do_all || ! strcmp (argv [1], "voc"))
-	{	pcm_test_char 	("char.voc" , SF_FORMAT_VOC | SF_FORMAT_PCM_U8, FALSE) ;
-		pcm_test_short	("short.voc", SF_FORMAT_VOC | SF_FORMAT_PCM_16, FALSE) ;
+	{	pcm_test_char 	("char.voc" , SF_FORMAT_VOC | SF_FORMAT_PCM_U8, SF_FALSE) ;
+		pcm_test_short	("short.voc", SF_FORMAT_VOC | SF_FORMAT_PCM_16, SF_FALSE) ;
 
 		test_count++ ;
 		} ;
 
 	if (do_all || ! strcmp (argv [1], "w64"))
-	{	pcm_test_char 	("char.w64"  , SF_FORMAT_W64 | SF_FORMAT_PCM_U8, FALSE) ;
-		pcm_test_short	("short.w64" , SF_FORMAT_W64 | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_24bit	("24bit.w64" , SF_FORMAT_W64 | SF_FORMAT_PCM_24, FALSE) ;
-		pcm_test_int	("int.w64"   , SF_FORMAT_W64 | SF_FORMAT_PCM_32, FALSE) ;
-		pcm_test_float	("float.w64" , SF_FORMAT_W64 | SF_FORMAT_FLOAT , FALSE) ;
-		pcm_test_double	("double.w64", SF_FORMAT_W64 | SF_FORMAT_DOUBLE, FALSE) ;
+	{	pcm_test_char 	("char.w64"  , SF_FORMAT_W64 | SF_FORMAT_PCM_U8, SF_FALSE) ;
+		pcm_test_short	("short.w64" , SF_FORMAT_W64 | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_24bit	("24bit.w64" , SF_FORMAT_W64 | SF_FORMAT_PCM_24, SF_FALSE) ;
+		pcm_test_int	("int.w64"   , SF_FORMAT_W64 | SF_FORMAT_PCM_32, SF_FALSE) ;
+		pcm_test_float	("float.w64" , SF_FORMAT_W64 | SF_FORMAT_FLOAT , SF_FALSE) ;
+		pcm_test_double	("double.w64", SF_FORMAT_W64 | SF_FORMAT_DOUBLE, SF_FALSE) ;
 
 		test_count++ ;
 		} ;
 
 	if (do_all || ! strcmp (argv [1], "mat4"))
-	{	pcm_test_short	("short_be.mat4" , SF_ENDIAN_BIG    | SF_FORMAT_MAT4 | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_short	("short_le.mat4" , SF_ENDIAN_LITTLE | SF_FORMAT_MAT4 | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_int	("int_be.mat4"   , SF_ENDIAN_BIG    | SF_FORMAT_MAT4 | SF_FORMAT_PCM_32, FALSE) ;
-		pcm_test_int 	("int_le.mat4"   , SF_ENDIAN_LITTLE | SF_FORMAT_MAT4 | SF_FORMAT_PCM_32, FALSE) ;
-		pcm_test_float	("float_be.mat4" , SF_ENDIAN_BIG    | SF_FORMAT_MAT4 | SF_FORMAT_FLOAT , FALSE) ;
-		pcm_test_float	("float_le.mat4" , SF_ENDIAN_LITTLE | SF_FORMAT_MAT4 | SF_FORMAT_FLOAT , FALSE) ;
-		pcm_test_double	("double_be.mat4", SF_ENDIAN_BIG    | SF_FORMAT_MAT4 | SF_FORMAT_DOUBLE, FALSE) ;
-		pcm_test_double	("double_le.mat4", SF_ENDIAN_LITTLE | SF_FORMAT_MAT4 | SF_FORMAT_DOUBLE, FALSE) ;
+	{	pcm_test_short	("short_be.mat4" , SF_ENDIAN_BIG    | SF_FORMAT_MAT4 | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_short	("short_le.mat4" , SF_ENDIAN_LITTLE | SF_FORMAT_MAT4 | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_int	("int_be.mat4"   , SF_ENDIAN_BIG    | SF_FORMAT_MAT4 | SF_FORMAT_PCM_32, SF_FALSE) ;
+		pcm_test_int 	("int_le.mat4"   , SF_ENDIAN_LITTLE | SF_FORMAT_MAT4 | SF_FORMAT_PCM_32, SF_FALSE) ;
+		pcm_test_float	("float_be.mat4" , SF_ENDIAN_BIG    | SF_FORMAT_MAT4 | SF_FORMAT_FLOAT , SF_FALSE) ;
+		pcm_test_float	("float_le.mat4" , SF_ENDIAN_LITTLE | SF_FORMAT_MAT4 | SF_FORMAT_FLOAT , SF_FALSE) ;
+		pcm_test_double	("double_be.mat4", SF_ENDIAN_BIG    | SF_FORMAT_MAT4 | SF_FORMAT_DOUBLE, SF_FALSE) ;
+		pcm_test_double	("double_le.mat4", SF_ENDIAN_LITTLE | SF_FORMAT_MAT4 | SF_FORMAT_DOUBLE, SF_FALSE) ;
 
 		test_count++ ;
 		} ;
 
 	if (do_all || ! strcmp (argv [1], "mat5"))
-	{	pcm_test_char 	("char_be.mat5"  , SF_ENDIAN_BIG    | SF_FORMAT_MAT5 | SF_FORMAT_PCM_U8, FALSE) ;
-		pcm_test_char 	("char_le.mat5"  , SF_ENDIAN_LITTLE | SF_FORMAT_MAT5 | SF_FORMAT_PCM_U8, FALSE) ;
-		pcm_test_short	("short_be.mat5" , SF_ENDIAN_BIG    | SF_FORMAT_MAT5 | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_short	("short_le.mat5" , SF_ENDIAN_LITTLE | SF_FORMAT_MAT5 | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_int	("int_be.mat5"   , SF_ENDIAN_BIG    | SF_FORMAT_MAT5 | SF_FORMAT_PCM_32, FALSE) ;
-		pcm_test_int 	("int_le.mat5"   , SF_ENDIAN_LITTLE | SF_FORMAT_MAT5 | SF_FORMAT_PCM_32, FALSE) ;
-		pcm_test_float	("float_be.mat5" , SF_ENDIAN_BIG    | SF_FORMAT_MAT5 | SF_FORMAT_FLOAT , FALSE) ;
-		pcm_test_float	("float_le.mat5" , SF_ENDIAN_LITTLE | SF_FORMAT_MAT5 | SF_FORMAT_FLOAT , FALSE) ;
-		pcm_test_double	("double_be.mat5", SF_ENDIAN_BIG    | SF_FORMAT_MAT5 | SF_FORMAT_DOUBLE, FALSE) ;
-		pcm_test_double	("double_le.mat5", SF_ENDIAN_LITTLE | SF_FORMAT_MAT5 | SF_FORMAT_DOUBLE, FALSE) ;
+	{	pcm_test_char 	("char_be.mat5"  , SF_ENDIAN_BIG    | SF_FORMAT_MAT5 | SF_FORMAT_PCM_U8, SF_FALSE) ;
+		pcm_test_char 	("char_le.mat5"  , SF_ENDIAN_LITTLE | SF_FORMAT_MAT5 | SF_FORMAT_PCM_U8, SF_FALSE) ;
+		pcm_test_short	("short_be.mat5" , SF_ENDIAN_BIG    | SF_FORMAT_MAT5 | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_short	("short_le.mat5" , SF_ENDIAN_LITTLE | SF_FORMAT_MAT5 | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_int	("int_be.mat5"   , SF_ENDIAN_BIG    | SF_FORMAT_MAT5 | SF_FORMAT_PCM_32, SF_FALSE) ;
+		pcm_test_int 	("int_le.mat5"   , SF_ENDIAN_LITTLE | SF_FORMAT_MAT5 | SF_FORMAT_PCM_32, SF_FALSE) ;
+		pcm_test_float	("float_be.mat5" , SF_ENDIAN_BIG    | SF_FORMAT_MAT5 | SF_FORMAT_FLOAT , SF_FALSE) ;
+		pcm_test_float	("float_le.mat5" , SF_ENDIAN_LITTLE | SF_FORMAT_MAT5 | SF_FORMAT_FLOAT , SF_FALSE) ;
+		pcm_test_double	("double_be.mat5", SF_ENDIAN_BIG    | SF_FORMAT_MAT5 | SF_FORMAT_DOUBLE, SF_FALSE) ;
+		pcm_test_double	("double_le.mat5", SF_ENDIAN_LITTLE | SF_FORMAT_MAT5 | SF_FORMAT_DOUBLE, SF_FALSE) ;
 
 		test_count++ ;
 		} ;
 
 	if (do_all || ! strcmp (argv [1], "pvf"))
-	{	pcm_test_char 	("char.pvf"  , SF_FORMAT_PVF | SF_FORMAT_PCM_S8, FALSE) ;
-		pcm_test_short	("short.w64" , SF_FORMAT_PVF | SF_FORMAT_PCM_16, FALSE) ;
-		pcm_test_int	("int.pvf"   , SF_FORMAT_PVF | SF_FORMAT_PCM_32, FALSE) ;
+	{	pcm_test_char 	("char.pvf"  , SF_FORMAT_PVF | SF_FORMAT_PCM_S8, SF_FALSE) ;
+		pcm_test_short	("short.pvf" , SF_FORMAT_PVF | SF_FORMAT_PCM_16, SF_FALSE) ;
+		pcm_test_int	("int.pvf"   , SF_FORMAT_PVF | SF_FORMAT_PCM_32, SF_FALSE) ;
+
+		test_count++ ;
+		} ;
+
+	if (do_all || ! strcmp (argv [1], "htk"))
+	{	pcm_test_short	("short.htk" , SF_FORMAT_HTK | SF_FORMAT_PCM_16, SF_FALSE) ;
 
 		test_count++ ;
 		} ;
@@ -298,10 +299,12 @@ pcm_test_char (char *filename, int filetype, int long_file_ok)
 
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
 
+	sf_set_string (file, SF_STR_ARTIST, "Your name here") ;
+
 	test_write_short_or_die (file, 0, orig, items, __LINE__) ;
 
 	/* Add non-audio data after the audio. */
-	sf_command (file, SFC_TEST_ADD_TRAILING_DATA, NULL, 0) ;
+	sf_set_string (file, SF_STR_COPYRIGHT, "Copyright (c) 2003") ;
 
 	sf_close (file) ;
 
@@ -539,11 +542,8 @@ pcm_test_char (char *filename, int filetype, int long_file_ok)
 	sfinfo.format 	   = filetype ;
 
 	if (! sf_format_check (&sfinfo))
-	{	/* SVX currently only supports mono. */
-		if ((filetype & SF_FORMAT_TYPEMASK) != SF_FORMAT_SVX)
-			printf ("ok, (no stereo)\n") ;
-		unlink (filename) ;
-		printf ("ok\n") ;
+	{	unlink (filename) ;
+		printf ("ok, (no stereo)\n") ;
 		return ;
 		} ;
 
@@ -560,9 +560,11 @@ pcm_test_char (char *filename, int filetype, int long_file_ok)
 
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
 
+	sf_set_string (file, SF_STR_ARTIST, "Your name here") ;
+
 	test_writef_short_or_die (file, 0, orig, frames, __LINE__) ;
 
-	sf_command (file, SFC_TEST_ADD_TRAILING_DATA, NULL, 0) ;
+	sf_set_string (file, SF_STR_COPYRIGHT, "Copyright (c) 2003") ;
 
 	sf_close (file) ;
 
@@ -702,10 +704,12 @@ pcm_test_short (char *filename, int filetype, int long_file_ok)
 
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
 
+	sf_set_string (file, SF_STR_ARTIST, "Your name here") ;
+
 	test_write_short_or_die (file, 0, orig, items, __LINE__) ;
 
 	/* Add non-audio data after the audio. */
-	sf_command (file, SFC_TEST_ADD_TRAILING_DATA, NULL, 0) ;
+	sf_set_string (file, SF_STR_COPYRIGHT, "Copyright (c) 2003") ;
 
 	sf_close (file) ;
 
@@ -943,11 +947,8 @@ pcm_test_short (char *filename, int filetype, int long_file_ok)
 	sfinfo.format 	   = filetype ;
 
 	if (! sf_format_check (&sfinfo))
-	{	/* SVX currently only supports mono. */
-		if ((filetype & SF_FORMAT_TYPEMASK) != SF_FORMAT_SVX)
-			printf ("ok, (no stereo)\n") ;
-		unlink (filename) ;
-		printf ("ok\n") ;
+	{	unlink (filename) ;
+		printf ("ok, (no stereo)\n") ;
 		return ;
 		} ;
 
@@ -964,9 +965,11 @@ pcm_test_short (char *filename, int filetype, int long_file_ok)
 
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
 
+	sf_set_string (file, SF_STR_ARTIST, "Your name here") ;
+
 	test_writef_short_or_die (file, 0, orig, frames, __LINE__) ;
 
-	sf_command (file, SFC_TEST_ADD_TRAILING_DATA, NULL, 0) ;
+	sf_set_string (file, SF_STR_COPYRIGHT, "Copyright (c) 2003") ;
 
 	sf_close (file) ;
 
@@ -1106,10 +1109,12 @@ pcm_test_24bit (char *filename, int filetype, int long_file_ok)
 
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
 
+	sf_set_string (file, SF_STR_ARTIST, "Your name here") ;
+
 	test_write_int_or_die (file, 0, orig, items, __LINE__) ;
 
 	/* Add non-audio data after the audio. */
-	sf_command (file, SFC_TEST_ADD_TRAILING_DATA, NULL, 0) ;
+	sf_set_string (file, SF_STR_COPYRIGHT, "Copyright (c) 2003") ;
 
 	sf_close (file) ;
 
@@ -1347,11 +1352,8 @@ pcm_test_24bit (char *filename, int filetype, int long_file_ok)
 	sfinfo.format 	   = filetype ;
 
 	if (! sf_format_check (&sfinfo))
-	{	/* SVX currently only supports mono. */
-		if ((filetype & SF_FORMAT_TYPEMASK) != SF_FORMAT_SVX)
-			printf ("ok, (no stereo)\n") ;
-		unlink (filename) ;
-		printf ("ok\n") ;
+	{	unlink (filename) ;
+		printf ("ok, (no stereo)\n") ;
 		return ;
 		} ;
 
@@ -1368,9 +1370,11 @@ pcm_test_24bit (char *filename, int filetype, int long_file_ok)
 
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
 
+	sf_set_string (file, SF_STR_ARTIST, "Your name here") ;
+
 	test_writef_int_or_die (file, 0, orig, frames, __LINE__) ;
 
-	sf_command (file, SFC_TEST_ADD_TRAILING_DATA, NULL, 0) ;
+	sf_set_string (file, SF_STR_COPYRIGHT, "Copyright (c) 2003") ;
 
 	sf_close (file) ;
 
@@ -1510,10 +1514,12 @@ pcm_test_int (char *filename, int filetype, int long_file_ok)
 
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
 
+	sf_set_string (file, SF_STR_ARTIST, "Your name here") ;
+
 	test_write_int_or_die (file, 0, orig, items, __LINE__) ;
 
 	/* Add non-audio data after the audio. */
-	sf_command (file, SFC_TEST_ADD_TRAILING_DATA, NULL, 0) ;
+	sf_set_string (file, SF_STR_COPYRIGHT, "Copyright (c) 2003") ;
 
 	sf_close (file) ;
 
@@ -1751,11 +1757,8 @@ pcm_test_int (char *filename, int filetype, int long_file_ok)
 	sfinfo.format 	   = filetype ;
 
 	if (! sf_format_check (&sfinfo))
-	{	/* SVX currently only supports mono. */
-		if ((filetype & SF_FORMAT_TYPEMASK) != SF_FORMAT_SVX)
-			printf ("ok, (no stereo)\n") ;
-		unlink (filename) ;
-		printf ("ok\n") ;
+	{	unlink (filename) ;
+		printf ("ok, (no stereo)\n") ;
 		return ;
 		} ;
 
@@ -1772,9 +1775,11 @@ pcm_test_int (char *filename, int filetype, int long_file_ok)
 
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
 
+	sf_set_string (file, SF_STR_ARTIST, "Your name here") ;
+
 	test_writef_int_or_die (file, 0, orig, frames, __LINE__) ;
 
-	sf_command (file, SFC_TEST_ADD_TRAILING_DATA, NULL, 0) ;
+	sf_set_string (file, SF_STR_COPYRIGHT, "Copyright (c) 2003") ;
 
 	sf_close (file) ;
 
@@ -1914,10 +1919,12 @@ pcm_test_float (char *filename, int filetype, int long_file_ok)
 
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
 
+	sf_set_string (file, SF_STR_ARTIST, "Your name here") ;
+
 	test_write_float_or_die (file, 0, orig, items, __LINE__) ;
 
 	/* Add non-audio data after the audio. */
-	sf_command (file, SFC_TEST_ADD_TRAILING_DATA, NULL, 0) ;
+	sf_set_string (file, SF_STR_COPYRIGHT, "Copyright (c) 2003") ;
 
 	sf_close (file) ;
 
@@ -2155,11 +2162,8 @@ pcm_test_float (char *filename, int filetype, int long_file_ok)
 	sfinfo.format 	   = filetype ;
 
 	if (! sf_format_check (&sfinfo))
-	{	/* SVX currently only supports mono. */
-		if ((filetype & SF_FORMAT_TYPEMASK) != SF_FORMAT_SVX)
-			printf ("ok, (no stereo)\n") ;
-		unlink (filename) ;
-		printf ("ok\n") ;
+	{	unlink (filename) ;
+		printf ("ok, (no stereo)\n") ;
 		return ;
 		} ;
 
@@ -2176,9 +2180,11 @@ pcm_test_float (char *filename, int filetype, int long_file_ok)
 
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
 
+	sf_set_string (file, SF_STR_ARTIST, "Your name here") ;
+
 	test_writef_float_or_die (file, 0, orig, frames, __LINE__) ;
 
-	sf_command (file, SFC_TEST_ADD_TRAILING_DATA, NULL, 0) ;
+	sf_set_string (file, SF_STR_COPYRIGHT, "Copyright (c) 2003") ;
 
 	sf_close (file) ;
 
@@ -2318,10 +2324,12 @@ pcm_test_double (char *filename, int filetype, int long_file_ok)
 
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
 
+	sf_set_string (file, SF_STR_ARTIST, "Your name here") ;
+
 	test_write_double_or_die (file, 0, orig, items, __LINE__) ;
 
 	/* Add non-audio data after the audio. */
-	sf_command (file, SFC_TEST_ADD_TRAILING_DATA, NULL, 0) ;
+	sf_set_string (file, SF_STR_COPYRIGHT, "Copyright (c) 2003") ;
 
 	sf_close (file) ;
 
@@ -2559,11 +2567,8 @@ pcm_test_double (char *filename, int filetype, int long_file_ok)
 	sfinfo.format 	   = filetype ;
 
 	if (! sf_format_check (&sfinfo))
-	{	/* SVX currently only supports mono. */
-		if ((filetype & SF_FORMAT_TYPEMASK) != SF_FORMAT_SVX)
-			printf ("ok, (no stereo)\n") ;
-		unlink (filename) ;
-		printf ("ok\n") ;
+	{	unlink (filename) ;
+		printf ("ok, (no stereo)\n") ;
 		return ;
 		} ;
 
@@ -2580,9 +2585,11 @@ pcm_test_double (char *filename, int filetype, int long_file_ok)
 
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
 
+	sf_set_string (file, SF_STR_ARTIST, "Your name here") ;
+
 	test_writef_double_or_die (file, 0, orig, frames, __LINE__) ;
 
-	sf_command (file, SFC_TEST_ADD_TRAILING_DATA, NULL, 0) ;
+	sf_set_string (file, SF_STR_COPYRIGHT, "Copyright (c) 2003") ;
 
 	sf_close (file) ;
 
